function [ E ] = dvojityodraz(  d_od,h_l,h_s,vzd,uhel,E0,f,R_koryto, R_voda  ) %od koryta i vody
% VSTUP: d_pr   - delka primeho paprsku
%        d_od   - delka odrazeneho paprsku
%        E0     - pocatecni intenzita pole
%        f      - frekvence vlny [MHz]
%        R      - koeficient odrazu

vln=((3*10^(8))/(f*10^(6)));
k=((2*pi())/(vln));
d_dvojod=delky_dvojodraz(d_od,h_l,h_s,vzd,uhel);
E1=((E0/d_dvojod)*exp(-1i*k*d_dvojod))*(R_voda*exp(-1i*pi()))*(R_koryto*exp(-1i*pi()));
E=E1;

end

